@@ -15,7 +15,3 @@ import jieba.analyse  as ja
 app = App()
 app.add_route('/get', lambda **kwargs: ja.tfidf(kwargs.get('text', '')), method="GET", result_key="keywords")
 app.run(port=9955, debug=False, reload=False)
-
-
-if __name__ == '__main__':
-    pass
\ No newline at end of file
