@@ -22,12 +22,14 @@ st.sidebar.markdown('**OCR SideBar**')
 biz = st.sidebar.selectbox('输入方式', ('ImageUrl', 'ImageFile'), index=0)
 
 if biz == 'ImageUrl':
-    ImageUrl = st.text_input("ImageUrl",
-                             "https://i1.mifile.cn/f/i/mioffice/img/slogan_5.png?1604383825042")
+    ImageUrl = st.text_input(
+        "ImageUrl",
+        "https://i1.mifile.cn/f/i/mioffice/img/slogan_5.png?1604383825042"
+    )
     input_image = 'image.png'
     # import wget
     # wget.download(ImageUrl, img_path)
-    os.system(f"wget {ImageUrl} -O {input_image}")
+    os.system(f"wget -q {ImageUrl} -O {input_image}")
     result = ocr.ocr(input_image, cls=True)
     output_image = ocr_result_image(result, input_image)
     st.image(output_image)
