@@ -8,18 +8,22 @@
 # @Software     : PyCharm
 # @Description  : 
 
+import os
 from PIL import Image
 from paddleocr import draw_ocr
 from appzoo.utils import get_module_path
 
 
 def ocr_result_image(result, input_image, output_image='output_image.png'):
-    # https://raw.githubusercontent.com/PaddlePaddle/PaddleOCR/develop/doc/simfang.ttf
+    if not os.path.exists('./simfang.ttf'):
+        os.system('wget https://raw.githubusercontent.com/PaddlePaddle/PaddleOCR/develop/doc/simfang.ttf')
+
     image = Image.open(input_image).convert('RGB')
     boxes = [line[0] for line in result]
     txts = [line[1][0] for line in result]
     scores = [line[1][1] for line in result]
-    im_show = draw_ocr(image, boxes, txts, scores, font_path=get_module_path("../data/simfang.ttf", __file__))
+    im_show = draw_ocr(image, boxes, txts, scores, font_path="./simfang.ttf")
+    # im_show = draw_ocr(image, boxes, txts, scores, font_path=get_module_path("../data/simfang.ttf", __file__))
     im_show = Image.fromarray(im_show)
     im_show.save(output_image)
     return output_image
